==> kolourpaint-4.9.5.tar.xz: kolourpaint-4.9.5/commands/imagelib/effects/kpEffectToneEnhanceCommand.cpp <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   Copyright (c) 2006 Mike Gashler <gashlerm@yahoo.com>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#include <kpEffectToneEnhanceCommand.h>

#include <kdebug.h>
#include <klocale.h>

#include <kpEffectToneEnhance.h>


kpEffectToneEnhanceCommand::kpEffectToneEnhanceCommand (double granularity, double amount,
        bool actOnSelection,
        kpCommandEnvironment *environ)
    : kpEffectCommandBase (i18n ("Histogram Equalizer"), actOnSelection, environ),
      m_granularity (granularity), m_amount (amount)
{
}

kpEffectToneEnhanceCommand::~kpEffectToneEnhanceCommand ()
{
}


// protected virtual [base kpEffectCommandBase]
kpImage kpEffectToneEnhanceCommand::applyEffect (const kpImage &image)
{
    return kpEffectToneEnhance::applyEffect (image, m_granularity, m_amount);
}

==> kolourpaint_16.08.3.orig.tar.xz: kolourpaint-16.08.3/commands/imagelib/effects/kpEffectToneEnhanceCommand.cpp <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   Copyright (c) 2006 Mike Gashler <gashlerm@yahoo.com>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#include "kpEffectToneEnhanceCommand.h"

#include "imagelib/effects/kpEffectToneEnhance.h"

#include <kdebug.h>
#include <klocale.h>


kpEffectToneEnhanceCommand::kpEffectToneEnhanceCommand (double granularity, double amount,
        bool actOnSelection,
        kpCommandEnvironment *environ)
    : kpEffectCommandBase (i18n ("Histogram Equalizer"), actOnSelection, environ),
      m_granularity (granularity), m_amount (amount)
{
}

kpEffectToneEnhanceCommand::~kpEffectToneEnhanceCommand ()
{
}


// protected virtual [base kpEffectCommandBase]
kpImage kpEffectToneEnhanceCommand::applyEffect (const kpImage &image)
{
    return kpEffectToneEnhance::applyEffect (image, m_granularity, m_amount);
}
